Index: src/ia32/lithium-ia32.cc |
diff --git a/src/ia32/lithium-ia32.cc b/src/ia32/lithium-ia32.cc |
index ba1abdc63291e15b6b225ad3df51a7465671537f..f16b2d27fb4d9b9b27e93727ce13bfe8f6dd54e8 100644 |
--- a/src/ia32/lithium-ia32.cc |
+++ b/src/ia32/lithium-ia32.cc |
@@ -2043,14 +2043,14 @@ LInstruction* LChunkBuilder::DoCheckInstanceType(HCheckInstanceType* instr) { |
} |
-LInstruction* LChunkBuilder::DoCheckFunction(HCheckFunction* instr) { |
- // If the target is in new space, we'll emit a global cell compare and so |
- // want the value in a register. If the target gets promoted before we |
+LInstruction* LChunkBuilder::DoCheckValue(HCheckValue* instr) { |
+ // If the object is in new space, we'll emit a global cell compare and so |
+ // want the value in a register. If the object gets promoted before we |
// emit code, we will still get the register but will do an immediate |
// compare instead of the cell compare. This is safe. |
- LOperand* value = instr->target_in_new_space() |
+ LOperand* value = instr->object_in_new_space() |
? UseRegisterAtStart(instr->value()) : UseAtStart(instr->value()); |
- return AssignEnvironment(new(zone()) LCheckFunction(value)); |
+ return AssignEnvironment(new(zone()) LCheckValue(value)); |
} |